@@ -91,22 +91,35 @@ def reader_function(path):
     channels = list(ds.channel.values)
 
     cube = []
-    ds = xr.open_zarr(store, group="l.16")
     bscale = 1
     bzero = 0
+    if "type" in ds.coords:
+        ds = ds.sel(type="mosaic").astype("float32")
     p1, p2 = get_display_range(ds["S001"].sel(z=0) * bscale + bzero)
     for group in ["", "l.2", "l.4", "l.8", "l.16"]:
         ds = xr.open_zarr(store, group=group)
         if "type" in ds.coords:  # v0.9 of pipeline
             ds = ds.sel(type="mosaic").astype("float32")
-        data = da.stack(
+        datalist = [
             [
-                (ds[s].sel(z=0).data.astype("float32") * bscale + bzero - p1)
+                (ds[s].sel(z=z).data.astype("float32") * bscale + bzero - p1)
                 / (p2 - p1)
                 * 10000
-                for s in list(ds)
+                for z in ds.z
             ]
-        )
+            for s in list(ds)
+        ]
+        datalist = [item for sublist in datalist for item in sublist]
+        data = da.stack(datalist)
+
+        # data = da.stack(
+        #     [
+        #         (ds[s].sel(z=0).data.astype("float32") * bscale + bzero - p1)
+        #         / (p2 - p1)
+        #         * 10000
+        #         for s in list(ds)
+        #     ]
+        # )
         cube.append(data)
 
     # optional kwargs for the corresponding viewer.add_* method
